pub struct TimelyProgressEvent {
pub is_send: bool,
pub worker: WorkerId,
pub channel: ChannelId,
pub seq_no: usize,
pub addr: OperatorAddr,
pub messages: Vec<MessageUpdate>,
pub internal: Vec<CapabilityUpdate>,
}Fields
is_send: booltrue if the event is a send, and false if it is a receive.
worker: WorkerIdSource worker index.
channel: ChannelIdCommunication channel identifier
seq_no: usizeMessage sequence number.
addr: OperatorAddrSequence of nested scope identifiers indicating the path from the root to this instance.
messages: Vec<MessageUpdate>List of message updates containing Target descriptor, timestamp as string, and delta.
internal: Vec<CapabilityUpdate>List of capability updates containing Source descriptor, timestamp as string, and delta.
Implementations
Sourceimpl TimelyProgressEvent
impl TimelyProgressEvent
pub fn new( is_send: bool, worker: WorkerId, channel: ChannelId, seq_no: usize, addr: OperatorAddr, messages: Vec<MessageUpdate>, internal: Vec<CapabilityUpdate>, ) -> Self