pub struct ApplicationEvent {
pub id: usize,
pub is_start: bool,
}Fields
id: usizeis_start: boolTrait Implementations
Sourceimpl Archive for ApplicationEvent
impl Archive for ApplicationEvent
Sourcetype Archived = ArchivedApplicationEvent
type Archived = ArchivedApplicationEvent
The archived representation of this type. Read more
Sourcetype Resolver = ApplicationEventResolver
type Resolver = ApplicationEventResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for ApplicationEvent
impl Clone for ApplicationEvent
Sourcefn clone(&self) -> ApplicationEvent
fn clone(&self) -> ApplicationEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApplicationEvent
impl Debug for ApplicationEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ApplicationEvent, __D> for Archived<ApplicationEvent>
impl<__D: Fallible + ?Sized> Deserialize<ApplicationEvent, __D> for Archived<ApplicationEvent>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ApplicationEvent, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ApplicationEvent, __D::Error>
Deserializes using the given deserializer
Sourceimpl From<ApplicationEvent> for ApplicationEvent
impl From<ApplicationEvent> for ApplicationEvent
Sourcefn from(event: TimelyApplicationEvent) -> Self
fn from(event: TimelyApplicationEvent) -> Self
Converts to this type from the input type.
Sourceimpl From<ApplicationEvent> for TimelyEvent
impl From<ApplicationEvent> for TimelyEvent
Sourcefn from(v: ApplicationEvent) -> Self
fn from(v: ApplicationEvent) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ApplicationEvent
impl Hash for ApplicationEvent
Sourceimpl Ord for ApplicationEvent
impl Ord for ApplicationEvent
Sourcefn cmp(&self, other: &ApplicationEvent) -> Ordering
fn cmp(&self, other: &ApplicationEvent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ApplicationEvent
impl PartialEq for ApplicationEvent
Sourceimpl PartialOrd for ApplicationEvent
impl PartialOrd for ApplicationEvent
impl Eq for ApplicationEvent
impl StructuralPartialEq for ApplicationEvent