pub struct ChannelsEvent {
pub id: ChannelId,
pub scope_addr: OperatorAddr,
pub source: [PortId; 2],
pub target: [PortId; 2],
}Expand description
The creation of a channel between two operators
Fields
id: ChannelIdThe id of the channel
scope_addr: OperatorAddrThe address of the enclosing scope the channel is in
source: [PortId; 2]The operator index and output port of the channel’s source
target: [PortId; 2]The operator index and input port of the channel’s target
Implementations
Sourceimpl ChannelsEvent
impl ChannelsEvent
Sourcepub const fn new(
id: ChannelId,
scope_addr: OperatorAddr,
source: (PortId, PortId),
target: (PortId, PortId),
) -> Self
pub const fn new( id: ChannelId, scope_addr: OperatorAddr, source: (PortId, PortId), target: (PortId, PortId), ) -> Self
Create a new ChannelsEvent