pub struct CommChannelsEvent {
pub identifier: usize,
pub kind: CommChannelKind,
}Fields
identifier: usizekind: CommChannelKindTrait Implementations
Sourceimpl Archive for CommChannelsEvent
impl Archive for CommChannelsEvent
Sourcetype Archived = ArchivedCommChannelsEvent
type Archived = ArchivedCommChannelsEvent
The archived representation of this type. Read more
Sourcetype Resolver = CommChannelsEventResolver
type Resolver = CommChannelsEventResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for CommChannelsEvent
impl Clone for CommChannelsEvent
Sourcefn clone(&self) -> CommChannelsEvent
fn clone(&self) -> CommChannelsEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommChannelsEvent
impl Debug for CommChannelsEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CommChannelsEvent, __D> for Archived<CommChannelsEvent>where
usize: Archive,
Archived<usize>: Deserialize<usize, __D>,
CommChannelKind: Archive,
Archived<CommChannelKind>: Deserialize<CommChannelKind, __D>,
impl<__D: Fallible + ?Sized> Deserialize<CommChannelsEvent, __D> for Archived<CommChannelsEvent>where
usize: Archive,
Archived<usize>: Deserialize<usize, __D>,
CommChannelKind: Archive,
Archived<CommChannelKind>: Deserialize<CommChannelKind, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CommChannelsEvent, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CommChannelsEvent, __D::Error>
Deserializes using the given deserializer
Sourceimpl From<CommChannelsEvent> for CommChannelsEvent
impl From<CommChannelsEvent> for CommChannelsEvent
Sourcefn from(event: TimelyCommChannelsEvent) -> Self
fn from(event: TimelyCommChannelsEvent) -> Self
Converts to this type from the input type.
Sourceimpl From<CommChannelsEvent> for TimelyEvent
impl From<CommChannelsEvent> for TimelyEvent
Sourcefn from(v: CommChannelsEvent) -> Self
fn from(v: CommChannelsEvent) -> Self
Converts to this type from the input type.
Sourceimpl Hash for CommChannelsEvent
impl Hash for CommChannelsEvent
Sourceimpl Ord for CommChannelsEvent
impl Ord for CommChannelsEvent
Sourcefn cmp(&self, other: &CommChannelsEvent) -> Ordering
fn cmp(&self, other: &CommChannelsEvent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CommChannelsEvent
impl PartialEq for CommChannelsEvent
Sourceimpl PartialOrd for CommChannelsEvent
impl PartialOrd for CommChannelsEvent
impl Eq for CommChannelsEvent
impl StructuralPartialEq for CommChannelsEvent