pub struct GuardedMessageEvent {
pub is_start: bool,
}Fields
is_start: boolTrait Implementations
Sourceimpl Archive for GuardedMessageEvent
impl Archive for GuardedMessageEvent
Sourcetype Archived = ArchivedGuardedMessageEvent
type Archived = ArchivedGuardedMessageEvent
The archived representation of this type. Read more
Sourcetype Resolver = GuardedMessageEventResolver
type Resolver = GuardedMessageEventResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for GuardedMessageEvent
impl Clone for GuardedMessageEvent
Sourcefn clone(&self) -> GuardedMessageEvent
fn clone(&self) -> GuardedMessageEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GuardedMessageEvent
impl Debug for GuardedMessageEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GuardedMessageEvent, __D> for Archived<GuardedMessageEvent>
impl<__D: Fallible + ?Sized> Deserialize<GuardedMessageEvent, __D> for Archived<GuardedMessageEvent>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GuardedMessageEvent, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GuardedMessageEvent, __D::Error>
Deserializes using the given deserializer
Sourceimpl From<GuardedMessageEvent> for GuardedMessageEvent
impl From<GuardedMessageEvent> for GuardedMessageEvent
Sourcefn from(event: TimelyGuardedMessageEvent) -> Self
fn from(event: TimelyGuardedMessageEvent) -> Self
Converts to this type from the input type.
Sourceimpl From<GuardedMessageEvent> for TimelyEvent
impl From<GuardedMessageEvent> for TimelyEvent
Sourcefn from(v: GuardedMessageEvent) -> Self
fn from(v: GuardedMessageEvent) -> Self
Converts to this type from the input type.
Sourceimpl Hash for GuardedMessageEvent
impl Hash for GuardedMessageEvent
Sourceimpl Ord for GuardedMessageEvent
impl Ord for GuardedMessageEvent
Sourcefn cmp(&self, other: &GuardedMessageEvent) -> Ordering
fn cmp(&self, other: &GuardedMessageEvent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GuardedMessageEvent
impl PartialEq for GuardedMessageEvent
Sourceimpl PartialOrd for GuardedMessageEvent
impl PartialOrd for GuardedMessageEvent
impl Eq for GuardedMessageEvent
impl StructuralPartialEq for GuardedMessageEvent