pub struct PushProgressEvent {
pub op_id: OperatorId,
}Fields
op_id: OperatorIdTrait Implementations
Sourceimpl Archive for PushProgressEventwhere
OperatorId: Archive,
impl Archive for PushProgressEventwhere
OperatorId: Archive,
Sourcetype Archived = ArchivedPushProgressEvent
type Archived = ArchivedPushProgressEvent
The archived representation of this type. Read more
Sourcetype Resolver = PushProgressEventResolver
type Resolver = PushProgressEventResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for PushProgressEvent
impl Clone for PushProgressEvent
Sourcefn clone(&self) -> PushProgressEvent
fn clone(&self) -> PushProgressEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PushProgressEvent
impl Debug for PushProgressEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PushProgressEvent, __D> for Archived<PushProgressEvent>
impl<__D: Fallible + ?Sized> Deserialize<PushProgressEvent, __D> for Archived<PushProgressEvent>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PushProgressEvent, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PushProgressEvent, __D::Error>
Deserializes using the given deserializer
Sourceimpl From<PushProgressEvent> for PushProgressEvent
impl From<PushProgressEvent> for PushProgressEvent
Sourcefn from(event: TimelyPushProgressEvent) -> Self
fn from(event: TimelyPushProgressEvent) -> Self
Converts to this type from the input type.
Sourceimpl From<PushProgressEvent> for TimelyEvent
impl From<PushProgressEvent> for TimelyEvent
Sourcefn from(v: PushProgressEvent) -> Self
fn from(v: PushProgressEvent) -> Self
Converts to this type from the input type.
Sourceimpl Hash for PushProgressEvent
impl Hash for PushProgressEvent
Sourceimpl Ord for PushProgressEvent
impl Ord for PushProgressEvent
Sourcefn cmp(&self, other: &PushProgressEvent) -> Ordering
fn cmp(&self, other: &PushProgressEvent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PushProgressEvent
impl PartialEq for PushProgressEvent
Sourceimpl PartialOrd for PushProgressEvent
impl PartialOrd for PushProgressEvent
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for PushProgressEventwhere
OperatorId: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for PushProgressEventwhere
OperatorId: Serialize<__S>,
impl Eq for PushProgressEvent
impl StructuralPartialEq for PushProgressEvent