pub struct ScheduleEvent {
pub id: OperatorId,
pub start_stop: StartStop,
}Fields
id: OperatorIdstart_stop: StartStopTrait Implementations
Sourceimpl Archive for ScheduleEvent
impl Archive for ScheduleEvent
Sourcetype Archived = ArchivedScheduleEvent
type Archived = ArchivedScheduleEvent
The archived representation of this type. Read more
Sourcetype Resolver = ScheduleEventResolver
type Resolver = ScheduleEventResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for ScheduleEvent
impl Clone for ScheduleEvent
Sourcefn clone(&self) -> ScheduleEvent
fn clone(&self) -> ScheduleEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScheduleEvent
impl Debug for ScheduleEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ScheduleEvent, __D> for Archived<ScheduleEvent>where
OperatorId: Archive,
Archived<OperatorId>: Deserialize<OperatorId, __D>,
StartStop: Archive,
Archived<StartStop>: Deserialize<StartStop, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ScheduleEvent, __D> for Archived<ScheduleEvent>where
OperatorId: Archive,
Archived<OperatorId>: Deserialize<OperatorId, __D>,
StartStop: Archive,
Archived<StartStop>: Deserialize<StartStop, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ScheduleEvent, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ScheduleEvent, __D::Error>
Deserializes using the given deserializer
Sourceimpl From<ScheduleEvent> for ScheduleEvent
impl From<ScheduleEvent> for ScheduleEvent
Sourcefn from(event: TimelyScheduleEvent) -> Self
fn from(event: TimelyScheduleEvent) -> Self
Converts to this type from the input type.
Sourceimpl From<ScheduleEvent> for TimelyEvent
impl From<ScheduleEvent> for TimelyEvent
Sourcefn from(v: ScheduleEvent) -> Self
fn from(v: ScheduleEvent) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ScheduleEvent
impl Hash for ScheduleEvent
Sourceimpl Ord for ScheduleEvent
impl Ord for ScheduleEvent
Sourcefn cmp(&self, other: &ScheduleEvent) -> Ordering
fn cmp(&self, other: &ScheduleEvent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ScheduleEvent
impl PartialEq for ScheduleEvent
Sourceimpl PartialOrd for ScheduleEvent
impl PartialOrd for ScheduleEvent
impl Eq for ScheduleEvent
impl StructuralPartialEq for ScheduleEvent