pub struct ShutdownEvent {
pub id: OperatorId,
}Fields
id: OperatorIdTrait Implementations
Sourceimpl Archive for ShutdownEventwhere
OperatorId: Archive,
impl Archive for ShutdownEventwhere
OperatorId: Archive,
Sourcetype Archived = ArchivedShutdownEvent
type Archived = ArchivedShutdownEvent
The archived representation of this type. Read more
Sourcetype Resolver = ShutdownEventResolver
type Resolver = ShutdownEventResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for ShutdownEvent
impl Clone for ShutdownEvent
Sourcefn clone(&self) -> ShutdownEvent
fn clone(&self) -> ShutdownEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShutdownEvent
impl Debug for ShutdownEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShutdownEvent, __D> for Archived<ShutdownEvent>
impl<__D: Fallible + ?Sized> Deserialize<ShutdownEvent, __D> for Archived<ShutdownEvent>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ShutdownEvent, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ShutdownEvent, __D::Error>
Deserializes using the given deserializer
Sourceimpl From<ShutdownEvent> for ShutdownEvent
impl From<ShutdownEvent> for ShutdownEvent
Sourcefn from(event: TimelyShutdownEvent) -> Self
fn from(event: TimelyShutdownEvent) -> Self
Converts to this type from the input type.
Sourceimpl From<ShutdownEvent> for TimelyEvent
impl From<ShutdownEvent> for TimelyEvent
Sourcefn from(v: ShutdownEvent) -> Self
fn from(v: ShutdownEvent) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ShutdownEvent
impl Hash for ShutdownEvent
Sourceimpl Ord for ShutdownEvent
impl Ord for ShutdownEvent
Sourcefn cmp(&self, other: &ShutdownEvent) -> Ordering
fn cmp(&self, other: &ShutdownEvent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ShutdownEvent
impl PartialEq for ShutdownEvent
Sourceimpl PartialOrd for ShutdownEvent
impl PartialOrd for ShutdownEvent
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for ShutdownEventwhere
OperatorId: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for ShutdownEventwhere
OperatorId: Serialize<__S>,
impl Eq for ShutdownEvent
impl StructuralPartialEq for ShutdownEvent